@@ -7,10 +7,10 @@ NumericVector calc_I_3(NumericMatrix X, int steps, float dt) {
   int paths = X.nrow();
 
   NumericVector I(paths);
-  double dt4 = dt*dt*dt*dt;
-  I = X(_, steps)/2 * steps * dt4;
+  I = X(_, steps)/2 * (steps * dt) * (steps * dt) * (steps * dt);
   for(i = 1; i < steps; i++) {
-    I = I + X(_, i) * i*i*i * dt4;
+    I = I + X(_, i) * (i * dt) * (i * dt) * (i * dt);
   }
+  I = I * dt;
   return I;
 }
