@@ -95,7 +95,10 @@ test_that("Binomial_American_Greeks is correct", {
 
   }
 
-  expect(max(error) < 0.1)
+  expect(
+    max(error) < 0.1,
+    failure_message = "The results of Binomial_American_Greeks.R cannot be
+    confirmend by finite difference")
 
 })
 
@@ -210,6 +213,8 @@ test_that("Binomial_American_Greeks fair_value is correct", {
     )
 
   }
-  expect(max(error) < 1e-5)
+  expect(max(error) < 1e-5,
+         failure_message = "The results of Binomial_American_Greeks.R cannot be
+    confirmend by Binomial_Americian_Greeks_test")
 
 })
